@@ -1,7 +1,5 @@
 from setuptools import setup
-
+print('===setup PGE===')
 setup(
-    ...
     scripts=['examples/pong/pygameextra-pong']
-    ...
 )
